RestoreOnPending

Struct RestoreOnPending 

pub struct RestoreOnPending(Cell<Budget>, PhantomData<*mut ()>);
Value returned by the poll_proceed method.

Tuple Fields

0: Cell<Budget>1: PhantomData<*mut ()>

Implementations



impl RestoreOnPending

pub fn made_progress(&self)

Signals that the task that obtained this RestoreOnPending was able to make progress. This prevents the task budget from being restored to the value it had prior to obtaining this instance when it is dropped.